Crate cw0[−][src]
Structs
| NativeBalance |
Enums
| Duration | Duration is a delta of time. You can add it to a BlockInfo or Expiration to move that further in the future. Note that an height-based Duration and a time-based Expiration cannot be combined |
| Expiration | Expiration represents a point in time when some event happens. It can compare with a BlockInfo and will return is_expired() == true once the condition is hit (and for every block in the future) |
| PaymentError |
Constants
| DAY | |
| HOUR | |
| WEEK |
Traits
| Event | This defines a set of attributes which should be added to |
Functions
| calc_range_end_human | |
| calc_range_start_human | |
| calc_range_start_string | |
| may_pay | Similar to must_pay, but it any payment is optional. Returns an error if a different
denom was sent. Otherwise, returns the amount of |
| maybe_canonical | |
| must_pay | Requires exactly one denom sent, which matches the requested denom. Returns the amount if only one denom and non-zero amount. Errors otherwise. |
| nonpayable | returns an error if any coins were sent |
| one_coin | If exactly one coin was sent, returns it regardless of denom. Returns error if 0 or 2+ coins were sent |